pub struct RowDeltaAction { /* private fields */ }Expand description
RowDeltaAction is a transaction action for encoding row-level changes to a table.
This action supports:
- Adding new data files
- Adding delete files (both position and equality deletes)
This is the appropriate action to use for:
- CDC (Change Data Capture) ingestion
- Upsert operations
- Row-level deletions
Example
ⓘ
use iceberg::transaction::Transaction;
let tx = Transaction::new(&table);
let action = tx.row_delta()
.add_data_files(new_data_files)
.add_delete_files(equality_delete_files);
let tx = action.apply(tx).unwrap();
let table = tx.commit(&catalog).await.unwrap();Implementations
Sourceimpl RowDeltaAction
impl RowDeltaAction
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new row delta action. Equivalent to crate::transaction::Transaction::row_delta.
Sourcepub fn with_check_duplicate(self, v: bool) -> Self
pub fn with_check_duplicate(self, v: bool) -> Self
Set whether to check duplicate files
Sourcepub fn add_data_files(
self,
data_files: impl IntoIterator<Item = DataFile>,
) -> Self
pub fn add_data_files( self, data_files: impl IntoIterator<Item = DataFile>, ) -> Self
Add data files to the snapshot.
Sourcepub fn add_delete_files(
self,
delete_files: impl IntoIterator<Item = DataFile>,
) -> Self
pub fn add_delete_files( self, delete_files: impl IntoIterator<Item = DataFile>, ) -> Self
Add delete files to the snapshot.
Delete files can be either position deletes or equality deletes. The content type of each file will be validated.
Sourcepub fn set_commit_uuid(self, commit_uuid: Uuid) -> Self
pub fn set_commit_uuid(self, commit_uuid: Uuid) -> Self
Set commit UUID for the snapshot.
Sourcepub fn set_snapshot_properties(
self,
snapshot_properties: HashMap<String, String>,
) -> Self
pub fn set_snapshot_properties( self, snapshot_properties: HashMap<String, String>, ) -> Self
Set snapshot summary properties.